@@ -1,8 +1,8 @@
-use getset::{CopyGetters, Getters};
+use getset::Getters;
 use serde::{Deserialize, Serialize};
 
-#[derive(Clone, Debug, Serialize, Deserialize, Getters, CopyGetters)]
-#[getset(get, get)]
+#[derive(Clone, Debug, Serialize, Deserialize, Getters)]
+#[getset(get = "pub")]
 pub struct User {
     login: String,
     id: usize,
